# Find CEGUI_OPENGL includes and library
#
# This module defines
#  CEGUI_OPENGL_INCLUDE_DIR
#  CEGUI_OPENGL_LIBRARIES, the libraries to link against to use CEGUI_OPENGL.
#  CEGUI_OPENGL_LIB_DIR, the location of the libraries
#  CEGUI_OPENGL_FOUND, If false, do not try to use CEGUI_OPENGL
#
# Copyright  2007, Matt Williams
# Modified by Nicolas Schlumberger to make it work on the Tardis-Infrastucture of the ETH Zurich
#
# Redistribution and use is allowed according to the terms of the BSD license.

IF (CEGUI_OPENGL_LIBRARIES AND CEGUI_OPENGL_INCLUDE_DIR)
    SET(CEGUI_OPENGL_FIND_QUIETLY TRUE) # Already in cache, be silent
ENDIF (CEGUI_OPENGL_LIBRARIES AND CEGUI_OPENGL_INCLUDE_DIR)

IF (WIN32) #Windows
    MESSAGE(STATUS "Looking for CEGUI_OPENGL")
    SET(CEGUI_OPENGLSDK $ENV{CEGUI_OPENGL_HOME})
    STRING(REGEX REPLACE "[\\]" "/" CEGUI_OPENGLSDK "${CEGUI_OPENGLSDK}" )
    SET(CEGUI_OPENGL_INCLUDE_DIR ${CEGUI_OPENGLSDK}/include)
    SET(CEGUI_OPENGL_LIB_DIR ${CEGUI_OPENGLSDK}/lib)
    SET(CEGUI_OPENGL_LIBRARIES debug OgreMain_d optimized OgreMain)
ELSE (WIN32) #Unix
    FIND_PACKAGE(PkgConfig)
    PKG_SEARCH_MODULE(CEGUI_OPENGL CEGUI-OPENGL /usr/pack/cegui-0.5.0-sd/i686-debian-linux3.1/lib/pkgconfig/CEGUI-OPENGL.pc) # tardis specific hack
    SET(CEGUI_OPENGL_INCLUDE_DIR ${CEGUI_OPENGL_INCLUDE_DIRS})
    SET(CEGUI_OPENGL_LIB_DIR ${CEGUI_OPENGL_LIBDIR})
    SET(CEGUI_OPENGL_LIBRARIES ${CEGUI_OPENGL_LIBRARIES} CACHE STRING "")
ENDIF (WIN32)

#Do some preparation
SEPARATE_ARGUMENTS(CEGUI_OPENGL_INCLUDE_DIR)
SEPARATE_ARGUMENTS(CEGUI_OPENGL_LIBRARIES)

SET(CEGUI_OPENGL_INCLUDE_DIR ${CEGUI_OPENGL_INCLUDE_DIR} CACHE PATH "")
SET(CEGUI_OPENGL_LIBRARIES ${CEGUI_OPENGL_LIBRARIES} CACHE STRING "")
SET(CEGUI_OPENGL_LIB_DIR ${CEGUI_OPENGL_LIB_DIR} CACHE PATH "")

IF (CEGUI_OPENGL_INCLUDE_DIR AND CEGUI_OPENGL_LIBRARIES)
    SET(CEGUI_OPENGL_FOUND TRUE)
ENDIF (CEGUI_OPENGL_INCLUDE_DIR AND CEGUI_OPENGL_LIBRARIES)

IF (CEGUI_OPENGL_FOUND)
    IF (NOT CEGUI_OPENGL_FIND_QUIETLY)
        MESSAGE(STATUS "  libraries : ${CEGUI_OPENGL_LIBRARIES} from ${CEGUI_OPENGL_LIB_DIR}")
        MESSAGE(STATUS "  includes  : ${CEGUI_OPENGL_INCLUDE_DIR}")
    ENDIF (NOT CEGUI_OPENGL_FIND_QUIETLY)
ELSE (CEGUI_OPENGL_FOUND)
    IF (CEGUI_OPENGL_FIND_REQUIRED)
        MESSAGE(FATAL_ERROR "Could not find CEGUI_OPENGL")
    ENDIF (CEGUI_OPENGL_FIND_REQUIRED)
ENDIF (CEGUI_OPENGL_FOUND)
